==> rechn_mgm_web-0.1.39.gem: spec/controllers/rechn_mgm_web/rechn_mgm_user_area/users_controller_spec.rb <==
require 'rails_helper'
require "refile/file_double"

module RechnMgmUserArea
    NoBrainer.sync_indexes
    RSpec.describe RechnMgmUserArea::UsersController, type: :controller do
        routes { RechnMgmUserArea::Engine.routes }

        before(:each) {
            # Cleanup
            NoBrainer.purge!
            NoBrainer::Document::Index::Synchronizer.new([Nukleus::Document, DeviseAuthentication::User]).sync_indexes

            # Create some users
            ## Buchhaltung1 who is currently in his own organisation and has an admin role as well
            @buchhaltung = DeviseAuthentication::User.new(email: "buchhaltung@test.de", forename: "Buchhalter", lastname: "Eins", password: "123456", password_confirmation: "123456" )
            expect(@buchhaltung.save).to eq(true)
            @membership_of_buchhalter = @buchhaltung.member_ships.where(is_primary: true).first
            @membership_of_buchhalter.roles_mask = 2 # Buchhalter
            @organisation_1 = @membership_of_buchhalter.organisation
            @buchhaltung.set_organisation(@organisation_1)
        }

        describe "Check Importing of Documents" do
            render_views

            it "check whether waiting documents can be read", :new_test => true do
                allow(controller).to receive(:current_user).and_return(@buchhaltung)
                @buchhaltung.waiting_documents = 2
                @buchhaltung.save

                get :documents_waiting_for_import, format: :json
                expect(response).to have_http_status(:ok)
                body_data = JSON.parse(response.body)
                expect(body_data["count"]).to eq(2)
            end

            it "use organisation for importing documents", :new_test => true do
                allow(controller).to receive(:current_user).and_return(@buchhaltung)
                expect(@buchhaltung.import_for_organisation_id).to be(nil)

                put :set_importing_organisation, :params => {organisation_id: @organisation_1.id}, format: :json
                expect(response).to have_http_status(:ok)

                body_data = JSON.parse(response.body)
                expect(body_data["code"]).to eq(0)

                @check_buchhaltung = DeviseAuthentication::User.find(@buchhaltung.id)
                expect(@check_buchhaltung.import_for_organisation_id).to eq(@organisation_1.id)
            end

            it "use membership for importing documents", :new_test => true do
                allow(controller).to receive(:current_user).and_return(@buchhaltung)
                expect(@buchhaltung.import_for_organisation_id).to be(nil)

                put :set_importing_organisation, :params => {organisation_id: @membership_of_buchhalter.id}, format: :json
                expect(response).to have_http_status(:ok)

                body_data = JSON.parse(response.body)
                expect(body_data["code"]).to eq(0)

                # Must still be the id of the organisation _not_ the membership
                @check_buchhaltung = DeviseAuthentication::User.find(@buchhaltung.id)
                expect(@check_buchhaltung.import_for_organisation_id).to eq(@organisation_1.id)
            end
        end
    end
end

==> rechn_mgm_web-0.1.40.gem: spec/controllers/rechn_mgm_web/rechn_mgm_user_area/users_controller_spec.rb <==
require 'rails_helper'
require "refile/file_double"

module RechnMgmUserArea
    NoBrainer.sync_indexes
    RSpec.describe RechnMgmUserArea::UsersController, type: :controller do
        routes { RechnMgmUserArea::Engine.routes }

        before(:each) {
            # Cleanup
            NoBrainer.purge!
            NoBrainer::Document::Index::Synchronizer.new([Nukleus::Document, DeviseAuthentication::User]).sync_indexes

            # Create some users
            ## Buchhaltung1 who is currently in his own organisation and has an admin role as well
            @buchhaltung = DeviseAuthentication::User.new(email: "buchhaltung@test.de", forename: "Buchhalter", lastname: "Eins", password: "123456", password_confirmation: "123456" )
            expect(@buchhaltung.save).to eq(true)
            @membership_of_buchhalter = @buchhaltung.member_ships.where(is_primary: true).first
            @membership_of_buchhalter.roles_mask = 2 # Buchhalter
            @organisation_1 = @membership_of_buchhalter.organisation
            @buchhaltung.set_organisation(@organisation_1)
        }

        describe "Check Importing of Documents" do
            render_views

            it "check whether waiting documents can be read" do
                allow(controller).to receive(:current_user).and_return(@buchhaltung)
                @buchhaltung.waiting_documents = 2
                @buchhaltung.save

                get :documents_waiting_for_import, format: :json
                expect(response).to have_http_status(:ok)
                body_data = JSON.parse(response.body)
                expect(body_data["count"]).to eq(2)
            end

            it "use organisation for importing documents" do
                allow(controller).to receive(:current_user).and_return(@buchhaltung)
                expect(@buchhaltung.import_for_organisation_id).to be(nil)

                put :set_importing_organisation, :params => {organisation_id: @organisation_1.id}, format: :json
                expect(response).to have_http_status(:ok)

                body_data = JSON.parse(response.body)
                expect(body_data["code"]).to eq(0)

                @check_buchhaltung = DeviseAuthentication::User.find(@buchhaltung.id)
                expect(@check_buchhaltung.import_for_organisation_id).to eq(@organisation_1.id)
            end

            it "use membership for importing documents" do
                allow(controller).to receive(:current_user).and_return(@buchhaltung)
                expect(@buchhaltung.import_for_organisation_id).to be(nil)

                put :set_importing_organisation, :params => {organisation_id: @membership_of_buchhalter.id}, format: :json
                expect(response).to have_http_status(:ok)

                body_data = JSON.parse(response.body)
                expect(body_data["code"]).to eq(0)

                # Must still be the id of the organisation _not_ the membership
                @check_buchhaltung = DeviseAuthentication::User.find(@buchhaltung.id)
                expect(@check_buchhaltung.import_for_organisation_id).to eq(@organisation_1.id)
            end
        end

        describe "Manage wep push token", :new_test => true do
            it "setting of new web push token" do
                allow(controller).to receive(:current_user).and_return(@buchhaltung)

                expect(@buchhaltung.web_push_user_token).to be_nil

                put :subscribe_web_push, :params => { id: @buchhaltung.id, player_id: "1234xyz" }, format: :json
                expect(response).to have_http_status(:ok)

                expect(@buchhaltung.web_push_user_token).to eq("1234xyz")

            end

            it "change of web push token", :new_test => true do
                allow(controller).to receive(:current_user).and_return(@buchhaltung)
                @buchhaltung.web_push_user_token = "1234xyz"
                expect(@buchhaltung.save).to eq(true)

                put :subscribe_web_push, :params => { id: @buchhaltung.id, player_id: "34567" }, format: :json
                expect(response).to have_http_status(:ok)

                expect(@buchhaltung.web_push_user_token).to eq("34567")
            end

            it "remove web push token", :new_test => true do
                allow(controller).to receive(:current_user).and_return(@buchhaltung)
                @buchhaltung.web_push_user_token = "1234xyz"
                expect(@buchhaltung.save).to eq(true)

                put :unsubscribe_web_push, :params => { id: @buchhaltung.id, player_id: "1234xyz" }, format: :json
                expect(response).to have_http_status(:ok)

                expect(@buchhaltung.web_push_user_token).to be_nil

            end


        end
    end
end
